@@ -14,7 +14,6 @@ import numpy as np
 # treeCl
 from collection import Collection, Scorer
 from clustering import Partition
-from software_interfaces.phyml import Phyml
 from constants import EPS, NEGINF, TMPDIR, ANALYSES
 from errors import optioncheck
 
@@ -38,10 +37,7 @@ class Optimiser(object):
         if scorer is not None and isinstance(scorer, Scorer):
             self.scorer = scorer
         else:
-            self.scorer = Scorer(self.Collection.records,
-                                 analysis=analysis,
-                                 datatype=self.datatype,
-                                 tmpdir=tmpdir)
+            self.scorer = Scorer(self.Collection)
 
         self.nclusters = nclusters
         self.tmpdir = tmpdir
@@ -208,12 +204,12 @@ class Optimiser(object):
                 print('Testing Clusters {0} and {1}'.format(i, j))
                 test_assignment = self.merge(assignment, i, j)
                 self.update(test_assignment)
-                score = self.scorer.score(test_assignment, history=False)
+                score_value = self.scorer.score(test_assignment, history=False)
 
-                if score > best_score:
+                if score_value > best_score:
                     merging[0] = i
                     merging[1] = j
-                    best_score = score
+                    best_score = score_value
                     best_assignment = test_assignment
 
         print('Merging clusters {0} and {1}'.format(*merging))
@@ -316,7 +312,7 @@ class Optimiser(object):
             for lab in extra_in_tree:
                 tmp_record.headers.append(lab)
                 tmp_record.sequences.append(''.join(['-'] * tmp_record.seqlength))
-            tmp_record._update()
+            tmp_record.update()
 
         if extra_in_record:
             for lab in extra_in_record:
@@ -325,7 +321,7 @@ class Optimiser(object):
                                       tmp_record.headers[i + 1:])
                 tmp_record.sequences = (tmp_record.sequences[:i] +
                                         tmp_record.sequences[i + 1:])
-            tmp_record._update()
+            tmp_record.update()
 
         return tmp_alignment.likelihood(tree, self.tmpdir, fit_rates=True)
         # alignment_file = tmp_record.write_phylip('{0}/tmp_alignment.phy'.format(
@@ -595,9 +591,7 @@ if __name__ == '__main__':
 
     c = Collection(input_dir=args.input_dir,
                    compression=args.compression,
-                   file_format=args.format,
-                   datatype=args.datatype,
-                   tmpdir=new_tmpdir)
+                   file_format=args.format)
 
     # Initial partitioning - either random or specified from a file
     if args.partition is not None:
